@@ -14,6 +14,11 @@ def _thresh_string(thresh, units):
         return "{} {}".format(str(thresh), units)
 
 
+def _filter_out_small_values(da, thresh, context=None):
+    thresh = convert_units_to(thresh, da, context=context)
+    return da.where(da > thresh)
+
+
 def _get_da(dictionary, var):
     if "ds" in dictionary.keys():
         return dictionary["ds"][var]
@@ -35,8 +40,14 @@ def _get_percentile(da, perc, base_period_time_range):
     return per_doy_comp.sel(percentiles=perc)
 
 
-def _convert_snow_mm_day(da):
-    return da / 312 * 1000
+def _convert_prsn_to_mm_day(da):
+    da = convert_units_to(da, "kg/(m**2*day)", context="hydro")
+    da.attrs["units"] = "kg/m**2"
+    snd = xc.land.snw_to_snd(snw=da)
+    da = convert_units_to(snd, "mm")
+    da.attrs["units"] = "mm/day"
+    da = da.rename("prsn")
+    return da
 
 
 BASE_PERIOD = ["1971-01-01", "2000-12-31"]
@@ -75,8 +86,13 @@ class CD:
                 base_period_time_range=base_period_time_range,
             )
         if perc_pr is None:
+            da_pr_f = _filter_out_small_values(
+                da_pr,
+                "1 mm/day",
+                context="hydro",
+            )
             perc_pr = _get_percentile(
-                da=da_pr,
+                da=da_pr_f,
                 perc=25,
                 base_period_time_range=base_period_time_range,
             )
@@ -245,8 +261,13 @@ class CW:
                 base_period_time_range=base_period_time_range,
             )
         if perc_pr is None:
+            da_pr_f = _filter_out_small_values(
+                da_pr,
+                "1 mm/day",
+                context="hydro",
+            )
             perc_pr = _get_percentile(
-                da=da_pr,
+                da=da_pr_f,
                 perc=75,
                 base_period_time_range=base_period_time_range,
             )
@@ -629,6 +650,7 @@ class RRYYp:
             Precip percentil value.
         """
         da = _get_da(params, "pr")
+        da = _filter_out_small_values(da, "1 mm/day", context="hydro")
         return _get_percentile(
             da=da,
             perc=perc,
@@ -660,16 +682,16 @@ class RYYp:
             Number of wet days over a given percentile.
         """
         da = _get_da(params, "pr")
+        da_pr = _filter_out_small_values(da, "1 mm/day", context="hydro")
         percentile = _get_percentile(
-            da=da,
+            da=da_pr,
             perc=perc,
             base_period_time_range=base_period_time_range,
         )
-        with dask.config.set(**{"array.slicing.split_large_chunks": False}):
-            return xc.atmos.days_over_precip_doy_thresh(
-                pr_per=percentile,
-                **params,
-            )
+        return xc.atmos.days_over_precip_doy_thresh(
+            pr_per=percentile,
+            **params,
+        )
 
 
 class RYYmm:
@@ -763,8 +785,9 @@ class RYYpABS:
             Precipitation fraction with precip > {perc}th percentile.
         """
         da = _get_da(params, "pr")
+        da_pr = _filter_out_small_values(da, "1 mm/day", context="hydro")
         pr_per = _get_percentile(
-            da=da,
+            da=da_pr,
             perc=perc,
             base_period_time_range=base_period_time_range,
         )
@@ -815,8 +838,9 @@ class RYYpTOT:
             Precipitation fraction with precip > {perc}th percentile.
         """
         da = _get_da(params, "pr")
+        da_pr = _filter_out_small_values(da, "1 mm/day", context="hydro")
         percentile = _get_percentile(
-            da=da,
+            da=da_pr,
             perc=perc,
             base_period_time_range=base_period_time_range,
         )
@@ -1309,8 +1333,13 @@ class WD:
                 base_period_time_range=base_period_time_range,
             )
         if perc_pr is None:
+            da_pr_f = _filter_out_small_values(
+                da_pr,
+                "1 mm/day",
+                context="hydro",
+            )
             perc_pr = _get_percentile(
-                da=da_pr,
+                da=da_pr_f,
                 perc=25,
                 base_period_time_range=base_period_time_range,
             )
@@ -1393,8 +1422,13 @@ class WW:
                 base_period_time_range=base_period_time_range,
             )
         if perc_pr is None:
+            da_pr_f = _filter_out_small_values(
+                da_pr,
+                "1 mm/day",
+                context="hydro",
+            )
             perc_pr = _get_percentile(
-                da=da_pr,
+                da=da_pr_f,
                 perc=75,
                 base_period_time_range=base_period_time_range,
             )
@@ -1506,12 +1540,10 @@ class SD:
         """
         thresh = _thresh_string(thresh, "mm/day")
         da = _get_da(params, "prsn")
-        prsn = _convert_snow_mm_day(da)
-        prsn = prsn.assign_attrs(**da.attrs)
-        prsn.attrs["units"] = "kg m-2 s-1"
+        da = _convert_prsn_to_mm_day(da)
         if "ds" in params.keys():
             del params["ds"]
-        params["prsn"] = prsn
+        params["prsn"] = da
         return xc.atmos.days_with_snow(
             low=thresh,
             **params,
@@ -1536,7 +1568,7 @@ class SCD:
         Number of days with snow cover above {thresh} threshold.
         """
         thresh = _thresh_string(thresh, "cm")
-        return xc.land.snow_cover_duration(
+        return xc.land.snd_season_length(
             thresh=thresh,
             **params,
         )
@@ -1557,10 +1589,11 @@ class Sint:
         """
 
         da = _get_da(params, "prsn")
-        prsn = _convert_snow_mm_day(da) * 86400
+        da = _convert_prsn_to_mm_day(da)
         if "ds" in params.keys():
             del params["ds"]
-        masked = xr.where(prsn > 1, prsn, np.nan)
+        params["prsn"] = da
+        masked = xr.where(da > 1, da, np.nan)
         mean = masked.resample(time=params["freq"]).mean(dim="time")
         return xr.where(mean == np.nan, 0, mean)
 
@@ -1582,12 +1615,10 @@ class Sfreq:
         """
         thresh = _thresh_string(1, "mm/day")
         da = _get_da(params, "prsn")
-        prsn = _convert_snow_mm_day(da)
-        prsn = prsn.assign_attrs(**da.attrs)
-        prsn.attrs["units"] = "kg m-2 s-1"
+        da = _convert_prsn_to_mm_day(da)
         if "ds" in params.keys():
             del params["ds"]
-        params["prsn"] = prsn
+        params["prsn"] = da
         sd = xc.atmos.days_with_snow(
             low=thresh,
             **params,
